@@ -7,8 +7,6 @@ if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 from textwrap import dedent
 
-from Testing import ZopeTestCase
-
 from App.Common import rfc1123_date
 from DateTime import DateTime
 from zExceptions import NotFound
@@ -17,22 +15,22 @@ from Interface.Verify import verifyObject
 
 from Products.CMFCore.utils import getToolByName
 
-from Products.PloneTestCase.PloneTestCase import PLONE21
+from Products.PloneTestCase.PloneTestCase import PLONE21, portal_owner, default_password
 
 from Products.ResourceRegistries.config import CSSTOOLNAME
 from Products.ResourceRegistries.interfaces.ResourceRegistries import ICSSRegistry as z2ICSSRegistry
-from Products.ResourceRegistries.tests import CSSRegistryTestCase
-from Products.ResourceRegistries.tests.five_tests_base import FiveTestsBase
+from Products.ResourceRegistries.tests.RegistryTestCase import RegistryTestCase
+from Products.ResourceRegistries.tests.RegistryTestCase import FunctionalRegistryTestCase
 
 
-class TestImplementation(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestImplementation(RegistryTestCase):
 
     def test_interfaces(self):
         tool = getattr(self.portal, CSSTOOLNAME)
         self.failUnless(z2ICSSRegistry.isImplementedBy(tool))
         self.failUnless(verifyObject(z2ICSSRegistry, tool))
 
-class TestTool(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestTool(RegistryTestCase):
 
     def testToolExists(self):
         self.failUnless(CSSTOOLNAME in self.portal.objectIds())
@@ -44,7 +42,7 @@ class TestTool(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless(tool.manage_cssComposition())
 
 
-class TestSkin(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestSkin(RegistryTestCase):
 
     def testSkins(self):
         skins = self.portal.portal_skins.objectIds()
@@ -54,7 +52,7 @@ class TestSkin(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless(getattr(self.portal, 'renderAllTheStylesheets'))
 
 
-class testZMIMethods(CSSRegistryTestCase.CSSRegistryTestCase):
+class testZMIMethods(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -66,7 +64,7 @@ class testZMIMethods(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless(self.tool.getResources())
 
 
-class TestStylesheetRegistration(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestStylesheetRegistration(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -129,7 +127,7 @@ class TestStylesheetRegistration(CSSRegistryTestCase.CSSRegistryTestCase):
         self.assertEqual(self.tool.getResourcesDict()['ham'].getId(), 'ham')
 
 
-class TestStylesheetRenaming(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestStylesheetRenaming(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -161,7 +159,7 @@ class TestStylesheetRenaming(CSSRegistryTestCase.CSSRegistryTestCase):
         self.assertRaises(ValueError, self.tool.renameResource, 'spam', 'bacon')
 
 
-class TestToolSecurity(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestToolSecurity(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -180,7 +178,7 @@ class TestToolSecurity(CSSRegistryTestCase.CSSRegistryTestCase):
             self.fail()
 
 
-class TestToolExpression(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestToolExpression(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -204,7 +202,7 @@ class TestToolExpression(CSSRegistryTestCase.CSSRegistryTestCase):
                         'python:"eggs" in object.objectIds()', context))
 
 
-class TestStylesheetCooking(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestStylesheetCooking(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -335,7 +333,7 @@ class TestStylesheetCooking(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless('background-color' in renderedpage)
 
 
-class TestStylesheetMoving(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestStylesheetMoving(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -452,7 +450,7 @@ class TestStylesheetMoving(CSSRegistryTestCase.CSSRegistryTestCase):
                          ('bacon', 'spam', 'eggs', 'ham'))
 
 
-class TestTraversal(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestTraversal(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -495,7 +493,7 @@ class TestTraversal(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless('background-color : red' in content)
         self.failUnless('H1 { color: blue; }' in content)
 
-class TestZODBTraversal(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestZODBTraversal(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -571,7 +569,7 @@ class TestZODBTraversal(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless('purple' in content)
         self.failIf('pink' in content)
 
-class TestMergingDisabled(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestMergingDisabled(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -698,7 +696,7 @@ class TestMergingDisabled(CSSRegistryTestCase.CSSRegistryTestCase):
         content = str(self.portal.restrictedTraverse('portal_css/test_rr_2.css'))
         self.failUnless('blue' in content)
 
-class TestPublishing(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestPublishing(FunctionalRegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -713,7 +711,7 @@ class TestPublishing(CSSRegistryTestCase.CSSRegistryTestCase):
     def testPublishCSSThroughTool(self):
         response = self.publish(self.toolpath + '/plone_styles.css')
         self.assertEqual(response.getStatus(), 200)
-        self.assertEqual(response.getHeader('Content-Type'), 'text/css')
+        self.assertEqual(response.getHeader('Content-Type'), 'text/css;charset=utf-8')
 
     def testPublishNonMagicCSSThroughTool(self):
         self.setRoles(['Manager'])
@@ -722,7 +720,7 @@ class TestPublishing(CSSRegistryTestCase.CSSRegistryTestCase):
         self.tool.registerStylesheet('testmethod')
         response = self.publish(self.toolpath + '/testmethod')
         self.assertEqual(response.getStatus(), 200)
-        self.assertEqual(response.getHeader('Content-Type'), 'text/css')
+        self.assertEqual(response.getHeader('Content-Type'), 'text/css;charset=utf-8')
 
     def testPublishPageWithInlineCSS(self):
         response = self.publish(self.portalpath)
@@ -740,23 +738,14 @@ class TestPublishing(CSSRegistryTestCase.CSSRegistryTestCase):
         self.assertEqual(response.getStatus(), 200)
 
 
-class TestFivePublishing(CSSRegistryTestCase.CSSRegistryTestCase, FiveTestsBase):
+class TestFivePublishing(FunctionalRegistryTestCase):
     'Publishing with Five'
 
     def afterSetUp(self):
-        FiveTestsBase.afterSetUp(self)
         # Define some resource
-        from Products.Five.zcml import load_string, load_config
-        load_string(dedent('''\
-                    <configure xmlns="http://namespaces.zope.org/zope"
-                           xmlns:browser="http://namespaces.zope.org/browser"
-                           xmlns:five="http://namespaces.zope.org/five">
-                        <browser:resource
-                                   name="test_rr_1.css"
-                                   file="test_rr_1.css"
-                          />
-                    </configure>'''))
-        #
+        from Products.Five.zcml import load_config
+        import Products.ResourceRegistries.tests
+        load_config('test.zcml', Products.ResourceRegistries.tests)
         self.tool = getattr(self.portal, CSSTOOLNAME)
         self.tool.clearResources()
         self.tool.registerStylesheet('++resource++test_rr_1.css')
@@ -773,7 +762,7 @@ class TestFivePublishing(CSSRegistryTestCase.CSSRegistryTestCase, FiveTestsBase)
         self.assertEqual('body { background-color : red }' in response.getBody(), True)
 
 
-class TestResourcePermissions(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestResourcePermissions(FunctionalRegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -788,7 +777,7 @@ class TestResourcePermissions(CSSRegistryTestCase.CSSRegistryTestCase):
                                    content_type='text/css',
                                    file='body { background-color : green }')
 
-        stylesheet = self.portal.restrictedTraverse('testroot.css')
+        stylesheet = getattr(self.portal, 'testroot.css')
 
         stylesheet.manage_permission('View',['Manager'], acquire=0)
         stylesheet.manage_permission('Access contents information',['Manager'], acquire=0)
@@ -852,13 +841,11 @@ class TestResourcePermissions(CSSRegistryTestCase.CSSRegistryTestCase):
             self.fail()
 
     def testAuthorizedOnPublish(self):
-        # FIXME - As a manager this should be accessible, but the test doesn't work
-        # when tested by hand in the browser, it does work as expected
-        self.setRoles(['Manager'])
-        response = self.publish(self.toolpath + '/testroot.css')
+        authstr = "%s:%s" % (portal_owner, default_password)
+        response = self.publish(self.toolpath + '/testroot.css', basic=authstr)
         self.failUnlessEqual(response.getStatus(), 200)
 
-class TestDebugMode(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestDebugMode(FunctionalRegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -895,46 +882,7 @@ class TestDebugMode(CSSRegistryTestCase.CSSRegistryTestCase):
         self.assertEqual(response.getHeader('Cache-Control'), 'max-age=0')
 
 
-class TestCSSDefaults(CSSRegistryTestCase.CSSRegistryTestCase):
-
-    def afterSetUp(self):
-        self.tool = getattr(self.portal, CSSTOOLNAME)
-
-    def testClearingStylesheets(self):
-        self.failUnless(self.tool.getResources())
-        self.tool.clearResources()
-        self.failIf(self.tool.getResources())
-
-    def testDefaultsInstall(self):
-        stylesheetids = self.tool.getResourceIds()
-        self.failUnless('plone.css' in stylesheetids)
-        self.failUnless('ploneColumns.css' in stylesheetids)
-        self.failUnless('ploneCustom.css' in stylesheetids)
-
-    def testTraverseToConcatenatedDefaults(self):
-        stylesheets = self.tool.getEvaluatedResources(self.portal)
-        for s in stylesheets:
-            try:
-                magicId = s.getId()
-                self.portal.restrictedTraverse('portal_css/%s' % magicId)
-            except KeyError:
-                self.fail()
-
-    def testCallingOfConcatenatedStylesheets(self):
-        stylesheets = self.tool.getEvaluatedResources(self.portal)
-        for s in stylesheets:
-            if 'ploneStyles' in s.getId():
-                output = self.portal.restrictedTraverse('portal_css/%s' % s.getId())
-                break
-        if not output:
-            self.fail()
-        o = str(output)[:]
-        self.failIf('&lt;dtml-call' in o)
-        self.failIf('&amp;dtml-fontBaseSize;' in o)
-        self.failUnless('** Plone style sheet for CSS2-capable browsers.' in o)
-
-
-class TestResourceObjects(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestResourceObjects(RegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -981,7 +929,7 @@ class TestResourceObjects(CSSRegistryTestCase.CSSRegistryTestCase):
                          ['eggs'])
 
 
-class TestSkinAwareness(CSSRegistryTestCase.CSSRegistryTestCase):
+class TestSkinAwareness(FunctionalRegistryTestCase):
 
     def afterSetUp(self):
         self.tool = getattr(self.portal, CSSTOOLNAME)
@@ -1022,177 +970,6 @@ class TestSkinAwareness(CSSRegistryTestCase.CSSRegistryTestCase):
         self.failUnless('purple' in str(response))
 
 
-class TestCSSCompression(CSSRegistryTestCase.CSSRegistryTestCase):
-    def afterSetUp(self):
-        self.tool = getattr(self.portal, CSSTOOLNAME)
-
-    def testCommentCompression(self):
-        input = """
-        /* this is a comment */
-        #testElement {
-            property: value; /* another comment */
-        }
-        /**********/
-        /* this is a multi
-           line comment */
-        #testElement {
-            /* yet another comment */
-            property: value;
-        }
-        """
-        expected = """/* */
-#testElement {
-property: value; /* */
-}
-/* */
-#testElement {
-/* */
-property: value;
-}
-"""
-        got = self.tool._compressCSS(input, 'safe')
-        self.assertEqual(got, expected)
-
-    def testNewlineCompression(self):
-        input = """
-        
-        
-        /* this is a comment */
-        
-        #testElement {
-            property: value; /* another comment */
-        }
-        
-        /* this is a multi
-           line comment */
-        #testElement {
-        
-            /* yet another comment */
-            property: value;
-            
-        }
-        
-        
-        """
-        expected = """/* */
-#testElement {
-property: value; /* */
-}
-/* */
-#testElement {
-/* */
-property: value;
-}
-"""
-        got = self.tool._compressCSS(input, 'safe')
-        self.assertEqual(got, expected)
-
-    def testCommentHacks(self):
-        # see http://www.dithered.com/css_filters/index.html
-        input = """
-        #testElement {
-            property/**/: value;
-            property/* */: value;
-            property /**/: value;
-            property: /**/value;
-        }
-        """
-        expected = """#testElement {
-property/**/: value;
-property/* */: value;
-property /**/: value;
-property: /**/value;
-}
-"""
-        got = self.tool._compressCSS(input, 'safe')
-        self.assertEqual(got, expected)
-
-        input = """
-        selector/* */ {  }
-        """
-        expected = """selector/* */ {  }
-"""
-        got = self.tool._compressCSS(input, 'safe')
-        self.assertEqual(got, expected)
-
-        input = """
-        selector/* foobar */ {  }
-        """
-        expected = """selector/* */ {  }
-"""
-        got = self.tool._compressCSS(input, 'safe')
-        self.assertEqual(got, expected)
-
-        input = """
-        selector/**/ {  }
-        """
-        expected = """selector/**/ {  }
-"""
-        got = self.tool._compressCSS(input, 'safe')
-        self.assertEqual(got, expected)
-
-        input = """
-        /* \*/
-        rules
-        /* */
-        """
-        expected = """/* \*/
-rules
-/* */
-"""
-        got = self.tool._compressCSS(input, 'safe')
-        self.assertEqual(got, expected)
-
-        input = """
-        /* foobar \*/
-        rules
-        /* */
-        """
-        expected = """/* \*/
-rules
-/* */
-"""
-        got = self.tool._compressCSS(input, 'safe')
-        self.assertEqual(got, expected)
-
-        input = """
-        /*/*/
-        rules
-        /* */
-        """
-        expected = """/*/*/
-rules
-/* */
-"""
-        got = self.tool._compressCSS(input, 'safe')
-        self.assertEqual(got, expected)
-
-        input = """
-        /*/*//*/
-        rules
-        /* */
-        """
-        expected = """/*/*//*/
-rules
-/* */
-"""
-        got = self.tool._compressCSS(input, 'safe')
-        self.assertEqual(got, expected)
-
-        input = """
-        /* test string protection and full compression */
-        #selector,
-        #another {
-            content: 'foo; bar';
-        }
-        """
-        expected = """/* */
-#selector,#another {content: 'foo; bar';}
-"""
-        got = self.tool._compressCSS(input, 'full')
-        self.assertEqual(got, expected)
-
-
 def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
@@ -1215,13 +992,6 @@ def test_suite():
     suite.addTest(makeSuite(TestDebugMode))
     suite.addTest(makeSuite(TestResourceObjects))
     suite.addTest(makeSuite(TestSkinAwareness))
-    suite.addTest(makeSuite(TestCSSCompression))
-
-    if not PLONE21:
-        # We must not test for the defaults in Plone 2.1 because they are
-        # all different. Plone2.1 has tests in CMFPlone/tests for defaults
-        # and migrations
-        suite.addTest(makeSuite(TestCSSDefaults))
 
     return suite
 
